import{o as e,a as s,q as i,b as l}from"./index-BSOHXgJs.js";const t=[l("div",{class:"absolute w-full h-full rounded-full border-4 border-t-positive-default border-positive-dimmest"},null,-1),l("div",{class:"w-2 h-2 z-10 rounded-full bg-positive-default animate-ping"},null,-1)],a={__name:"SLLoading",props:{size:{type:String,default:"8"}},setup:l=>(a,d)=>(e(),s("div",{class:i(["relative flex items-center justify-center rounded-full overflow-hidden animate-spin",l.size?`w-${l.size} h-${l.size}`:"w-8 h-8"])},t,2))};export{a as _};
