import{K as e,d as s,o as a,a as l,b as t,t as r,F as n,s as m,f as p,N as u,c as o,e as i,g as c}from"./index-BSOHXgJs.js";import{E as d}from"./EnvItems-CNxkMiS2.js";const v={key:0,class:"flex flex-col gap-y-4 pt-4"},y={class:"w-full flex"},f=t("span",{class:"text-dimmer w-44"},"GPU count",-1),x={class:"text-dimmer w-44"},w={class:"w-96 break-words whitespace-wrap shrink"},b={class:"shrink-0 pl-8"},k={__name:"EnvGPUItem",setup(u){const o=e().experiment.system;return(e,u)=>{var i,c;return(null==(i=s(o).gpu)?void 0:i.cores)?(a(),l("div",v,[t("div",y,[f,t("span",null,r(null==(c=s(o).gpu)?void 0:c.cores),1)]),(a(!0),l(n,null,m(s(o).gpu.memory,((e,n)=>(a(),l("div",{class:"w-full flex",key:n},[t("span",x,"GPU"+r(n),1),t("span",w,r(s(o).gpu.type[n]),1),t("span",b,r(e)+" GB",1)])))),128))])):p("",!0)}}},g={class:"w-full border p-6 rounded-lg bg-default"},h={class:"w-full text-xl font-semibold pb-4 border-b mb-2"},G={key:0},E=[t("p",{class:"text-center pt-5"},"No hardware information",-1)],_={__name:"EnvHardware",setup(v){const y=e(),f=y.experiment.system,x=u(),w=o((()=>[b.value])),b=o((()=>[{key:"cpu",value:f.cpu},{key:"memory",value:f.memory?f.memory+"GB":""}]));return(e,u)=>(a(),l("div",g,[t("h1",h,r(e.$t(`experiment.env.title.${s(x).name}`)),1),(a(!0),l(n,null,m(w.value,(e=>(a(),c(d,{data:e,key:e},null,8,["data"])))),128)),i(k),0===Object.keys(s(y).experiment.system).length?(a(),l("div",G,E)):p("",!0)]))}};export{_ as default};
