import{_ as e,o as a,a as t,b as n,t as l,g as s,f as i,q as o,ak as u,m as r,C as p,c as v,F as y,s as c}from"./index-BSOHXgJs.js";const d={key:0,class:"w-full flex relative"},h={class:"text-dimmer w-44 shrink-0"},k={key:0},g=["href"],f=e({__name:"EnvItem",props:{envKey:{type:[String,Number],default:""},envValue:{type:[String,Number],default:""},highLight:{type:Boolean,default:!1},link:{type:Boolean,default:!1},copy:{type:Boolean,default:!1}},setup:e=>(v,y)=>{const c=p;return e.envValue?(a(),t("div",d,[n("span",h,l(v.$t(`experiment.env.keys.${e.envKey}`)),1),n("span",{class:o(["item",{"high-light":e.highLight,copy:e.copy}]),onClick:y[0]||(y[0]=a=>{return e.copy&&(t=e.envValue,u(t),void r.success("Copy!"));var t})},[e.link?(a(),t("a",{key:1,href:e.envValue,target:"_blank",class:"hover:underline underline-offset-2"},l(e.envValue),9,g)):(a(),t("span",k,l(e.envValue),1)),e.copy?(a(),s(c,{key:2,icon:"copy",class:"copy-button"})):i("",!0)],2)])):i("",!0)}},[["__scopeId","data-v-aad3d441"]]),m={key:0,class:"env-items"},_=e({__name:"EnvItems",props:{data:{type:Array,default:()=>[]}},setup(e){const n=e,l=v((()=>n.data.filter((e=>e.value)).length>0));return(n,o)=>{var u;return 0!==(null==(u=e.data)?void 0:u.length)&&l.value?(a(),t("div",m,[(a(!0),t(y,null,c(e.data,(e=>(a(),s(f,{"env-key":e.key,"env-value":e.value,key:e.key,highLight:e.highLight,copy:e.copy,link:e.link},null,8,["env-key","env-value","highLight","copy","link"])))),128))])):i("",!0)}}},[["__scopeId","data-v-afaf93c7"]]);export{_ as E};
