import{N as e,K as a,u as t,c as i,o as l,a as o,b as s,t as u,d as n,F as r,s as v,B as d,g as y}from"./index-BSOHXgJs.js";import{E as g}from"./EnvItems-CNxkMiS2.js";const m={class:"w-full border p-6 rounded-lg bg-default"},h={class:"w-full text-xl font-semibold pb-4 border-b mb-2"},c={__name:"EnvIndex",setup(c){const p=e(),k=a(),b=t(),_=k.experiment,f=_.system,x=i((()=>[w.value,L.value,E.value,$.value])),w=i((()=>[{key:"start_time",value:d(_.create_time)},{key:"duration",value:k.duration},{key:"hostname",value:f.hostname},{key:"OS",value:f.os},{key:"pid",value:f.pid}])),L=i((()=>[{key:"python",value:f.python},{key:"verbose",value:f.python_verbose},{key:"executable",value:f.executable,highLight:!0,copy:!0},{key:"workspace",value:f.cwd,highLight:!0,copy:!0},{key:"command",value:f.command,highLight:!0,copy:!0}])),E=i((()=>[{key:"git_remote",value:f.git_remote,highLight:!0,link:!0},{key:"git_branch",value:f.git_info?f.git_info[0]:""},{key:"git_commit",value:f.git_info?f.git_info[1]:"",copy:!0}])),$=i((()=>[{key:"logdir",value:b.logdir+(b.logdir.includes("/")?"/":"\\")+_.run_id,highLight:!0,copy:!0},{key:"swanlab",value:`v${_.version}`}]));return(e,a)=>(l(),o("div",m,[s("h1",h,u(e.$t(`experiment.env.title.${n(p).name}`)),1),(l(!0),o(r,null,v(x.value,(e=>(l(),y(g,{data:e,key:e},null,8,["data"])))),128))]))}};export{c as default};
