import{o as e,a as s,b as t,t as a,e as o,w as r,D as l,H as d}from"./index-BSOHXgJs.js";const i={class:"w-full flex flex-col items-center pt-10"},m=t("h1",{class:"text-5xl font-semibold"},"404",-1),n={class:"py-4 text-dimmer font-semibold text-lg"},p={__name:"NotFound",setup:p=>(p,c)=>(e(),s("div",i,[m,t("p",n,a(p.$t("error.404.message")),1),o(l,{class:"px-4 py-1.5 border rounded-lg",onClick:c[0]||(c[0]=e=>p.$router.replace("/")),theme:"positive"},{default:r((()=>[d(a(p.$t("error.404.return")),1)])),_:1})]))};export{p as default};
