.magnifier[data-v-9779dd79]{height:2.5rem;width:2.5rem;animation:animloader-9779dd79 3s infinite}@keyframes animloader-9779dd79{0%{transform:translate(-5px,-5px)}25%{transform:translate(-5px,5px)}50%{transform:translate(5px,5px)}75%{transform:translate(5px,-5px)}to{transform:translate(-5px,-5px)}}
